@@ -58,7 +58,7 @@ class Irregularity(BaseModel):
     irregularity_ID: uuid.UUID
     source: Source
     time_label: str
-    irregularity_type: IrregularityType = None
+    irregularity_type: IrregularityType | None = None
     irregularity_properties: IrregularityProperties | None = None
     image_URI: str | None = None
     audio_block_URI: str | None = None
@@ -120,7 +120,7 @@ class Irregularity(BaseModel):
 class IrregularityFile(BaseModel):
     # TODO: the offset calculation is not implemented yet, so it is set to None
     irregularities: list[Irregularity]
-    offset: Annotated[int, Field(default=0)]
+    offset: int | None = None
 
     class Config:
         schema_extra = {
